@@ -1,6 +1,3 @@
-__author__ = 'Cecilia Assis'
-__version__ = '0.1.0'
-
 import pandas as pd
 from sklearn.preprocessing import normalize as norm
 
@@ -14,6 +11,7 @@ def normalize_confusion_matrix(confusion_matrix: DF) -> DF:
     ----------
     confusion_matrix : pandas.DataFrame
         Dataframe containing the original confusion matrix.
+
     Returns
     -------
     matrix : pandas.DataFrame
