@@ -1,12 +1,10 @@
-__author__ = 'Cecilia Assis'
-__version__ = '0.1.0'
-
 import matplotlib
 import matplotlib.patheffects as path_effects
 import matplotlib.pyplot as plt
 
 AX = matplotlib.axes.Axes
 
+
 def plot_text(text: str, title: str, title_size: int = 30) -> AX:
     """Plots a text.
 
